function dx = mydyn(t,x,u) 
% Cette fonction calcule le modele d'etat pour le reservoir thermostatise

% Commentaire: cette semaine on met la fonction dynamique dans une fonction .m apart
% car cela donne plus de flexibilite. C'est l'approche a utiliser en general.

%-----------------------------------------------------------------------------------
% Definition des parametres physiques 
%-----------------------------------------------------------------------------------
V = 1;      % Volume reservoir [m^3]
V_m = .5;   % Volume circuit de refroidissement [m^3]
rho = 1;    % Masse volumique [kg/m^3]
rho_m = 5;  % Masse volumique fluide de refroidissement [kg/m^3]
c_p = 4200; % Chaleur specifique [J/kgK]
c_pm = 1650;% Chaleur specifique liquide de refroidissement [J/kgK] 
h = 100;    % Coefficient d'echange thermique avec le circuit [W/m^2K] 
A = 1;      % Surface d'echange avec le circuit [m^2]
h_e = 200;  % Coefficient d'echange thermique avec l'air [W/m^2K] 
A_e = 3;    % Surface d'echange avec l'air [m^2]
h_t = 140;  % Coefficient d'echange thermique avec la sonde [W/m^2K]
A_t = 2;    % Surface d'echange avec la sonde [m^2]
hd_e = 350; % Coefficient d'echange thermique manteau-air [W/m^2K]
Ad_e = 1.2; % Surface d'echange manteau-air [m^2]
C_t = 200;  % [J/K]

%-----------------------------------------------------------------------------------
% Definir les etats et les entrees
%-----------------------------------------------------------------------------------
% On renomme les etats et les entrees car il est plus facile de reperer des 
% eventuelles erreurs en utilisant des noms de variables comme 'T', au lieu de x(1)

T = x(1);
T_m = x(2);
T_t = x(3);

w = u(1);
T_in = u(2);
T_e = u(3);

%-----------------------------------------------------------------------------------
% Modele d'etat: dx = f(x,u)
%-----------------------------------------------------------------------------------

dT = (V*rho*c_p)^(-1)*(h*A*(T_m-T)+h_e*A_e*(T_e-T)+h_t*A_t*(T_t-T));
dT_m = (V_m*rho_m*c_pm)^(-1)*(w*c_pm*(T_in-T_m)+h*A*(T-T_m)+hd_e*Ad_e*(T_e-T_m));
dT_t = (C_t)^(-1)*(h_t*A_t*(T-T_t));

dx = [dT, dT_m, dT_t]';